@@ -32,6 +32,7 @@
 
 #if WITH_BACKTRACE
 static struct backtrace_state *state = NULL;
+static int frames_omitted_count = 0;
 #endif
 
 static void
@@ -50,9 +51,23 @@ exm_backtrace_full_cb (GString    *string_builder,
                        const char *function)
 {
     char *entry;
+
     entry = g_strdup_printf ("%s:%d '%s'\n", filename, lineno, function);
-    g_string_append (string_builder, entry);
-    g_free (entry);
+
+    if (strstr (entry, "null") != NULL)
+        frames_omitted_count++;
+    else
+    {
+        if (frames_omitted_count > 0)
+        {
+            g_string_append_printf (string_builder, "%d frame%s omitted\n",
+                                    frames_omitted_count,
+                                    (frames_omitted_count > 1) ? "s" : "");
+            frames_omitted_count = 0;
+        }
+        g_string_append (string_builder, entry);
+        g_free (entry);
+    }
 
     return 0;
 }
